/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.farm.model;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.IOException;
import java.io.Serializable;
import java.util.Objects;
import nl.cloudfarming.client.crop.model.CropDefinition;

/**
 * Model class for production unit.
 * 
 * A crop production unit is an administrative unit and collection of crop fields.
 * 
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class CropProductionUnit implements Serializable{
    private static final long serialVersionUID = 1L;
    
    public static final String MIME_TYPE = "application/x-agrosense-cropproductionunit";

    private CropDefinition crop;
    public static final String PROP_CROP = "crop";

    private Double plannedHectares;
    public static final String PROP_PLANNED_HECTARES = "plannedHectares";
    
    private String name;
    public static final String PROP_NAME = "name";

    /**
     * Get the value of name
     *
     * @return the value of name
     */
    public String getName() {
        return name;
    }

    /**
     * Set the value of name
     *
     * @param name new value of name
     */
    public void setName(String name) {
        String oldName = this.name;
        this.name = name;
        propertyChangeSupport.firePropertyChange(PROP_NAME, oldName, name);
    }


    /**
     * Get the value of plannedSurrface
     *
     * @return the value of plannedSurrface
     */
    public Double getPlannedHectares() {
        return plannedHectares;
    }

    /**
     * Set the value of plannedSurrface
     *
     * @param plannedSurrface new value of plannedSurrface
     */
    public void setPlannedSurrface(Double plannedHectares) {
        Double oldPlannedHectares = this.plannedHectares;
        this.plannedHectares = plannedHectares;
        propertyChangeSupport.firePropertyChange(PROP_PLANNED_HECTARES, oldPlannedHectares, plannedHectares);
    }

    
    
    /**
     * Get the value of crop
     *
     * @return the value of crop
     */
    public CropDefinition getCrop() {
        return crop;
    }

    /**
     * Set the value of crop
     *
     * @param crop new value of crop
     */
    public void setCrop(CropDefinition crop) {
        CropDefinition oldCrop = this.crop;
        this.crop = crop;
        propertyChangeSupport.firePropertyChange(PROP_CROP, oldCrop, crop);
    }
    
    private transient PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);

    /**
     * Add PropertyChangeListener.
     *
     * @param listener
     */
    public void addPropertyChangeListener(PropertyChangeListener listener) {
        propertyChangeSupport.addPropertyChangeListener(listener);
    }

    /**
     * Remove PropertyChangeListener.
     *
     * @param listener
     */
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        propertyChangeSupport.removePropertyChangeListener(listener);
    }

    private void readObject(java.io.ObjectInputStream in)
            throws IOException, ClassNotFoundException {
        in.defaultReadObject();
        propertyChangeSupport = new PropertyChangeSupport(this);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final CropProductionUnit other = (CropProductionUnit) obj;
        if (!Objects.equals(this.name, other.name)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 41 * hash + Objects.hashCode(this.name);
        return hash;
    }
    
    
}
